#[repr(C)]struct InternalNode<K, V> {
data: LeafNode<K, V>,
edges: [MaybeUninit<NonNull<LeafNode<K, V>>>; 12],
}Expand description
The underlying representation of internal nodes. As with LeafNodes, these should be hidden
behind BoxedNodes to prevent dropping uninitialized keys and values. Any pointer to an
InternalNode can be directly cast to a pointer to the underlying LeafNode portion of the
node, allowing code to act on leaf and internal nodes generically without having to even check
which of the two a pointer is pointing at. This property is enabled by the use of repr(C).
Fields
data: LeafNode<K, V>edges: [MaybeUninit<NonNull<LeafNode<K, V>>>; 12]The pointers to the children of this node. len + 1 of these are considered
initialized and valid, except that near the end, while the tree is held
through borrow type Dying, some of these pointers are dangling.
Implementations
Sourceimpl<K, V> InternalNode<K, V>
impl<K, V> InternalNode<K, V>
Sourceunsafe fn new<A: AllocatorClone>(alloc: A) -> Box<Self, A>
unsafe fn new<A: AllocatorClone>(alloc: A) -> Box<Self, A>
Creates a new boxed InternalNode.
Safety
An invariant of internal nodes is that they have at least one initialized and valid edge. This function does not set up such an edge.